/*
 *   Copyright 2012 Brian Rosenberger (Brutex Network)
 *
 *   Licensed under the Apache License, Version 2.0 (the "License");
 *   you may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 */

package net.brutex.xservices.types.scm;

import java.io.File;
import java.util.ArrayList;
import java.util.List;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * @author Brian Rosenberger, bru(at)brutex.de
 * @since 0.5.0-20120817
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(propOrder={"localFilename", "repositoryFilename", "description", "headRevision", "branch", "totalRevisions", "revisions"})
@XmlRootElement
public class FileType {
	
	String localFilename;
	String repositoryFilename;
	String description;
	String headRevision;
	String branch;
	String totalRevisions;
	final List<Revision> revisions = new ArrayList<Revision>();
	
	/**
	 * @return the revisions
	 */
	public List<Revision> getRevisions() {
		return revisions;
	}

	public void addRevision(Revision revision) {
		this.revisions.add(revision);
	}

	/**
	 * @return the totalRevisions
	 */
	public String getTotalRevisions() {
		return totalRevisions;
	}

	/**
	 * @param totalRevisions the totalRevisions to set
	 */
	public void setTotalRevisions(String totalRevisions) {
		this.totalRevisions = totalRevisions;
	}

	public FileType() {
	}
	
	public FileType(File file, String repositoryname, String description) {
		if(file!= null ) {
			this.localFilename = file.toURI().toString();
		} else {
			localFilename = "";
		}
		
		this.repositoryFilename = repositoryname;
		this.description = description;
	}

	/**
	 * @return the localFilename
	 */
	public String getLocalFilename() {
		return localFilename;
	}

	/**
	 * @param localFilename the localFilename to set
	 */
	public void setLocalFilename(String localFilename) {
		this.localFilename = localFilename;
	}

	/**
	 * @return the repositoryFilename
	 */
	public String getRepositoryFilename() {
		return repositoryFilename;
	}

	/**
	 * @param repositoryFilename the repositoryFilename to set
	 */
	public void setRepositoryFilename(String repositoryFilename) {
		this.repositoryFilename = repositoryFilename;
	}

	/**
	 * @return the description
	 */
	public String getDescription() {
		return description;
	}

	/**
	 * @param description the description to set
	 */
	public void setDescription(String description) {
		this.description = description;
	}

	/**
	 * @return the headRevision
	 */
	public String getHeadRevision() {
		return headRevision;
	}

	/**
	 * @param headRevision the headRevision to set
	 */
	public void setHeadRevision(String headRevision) {
		this.headRevision = headRevision;
	}

	/**
	 * @return the branch
	 */
	public String getBranch() {
		return branch;
	}

	/**
	 * @param branch the branch to set
	 */
	public void setBranch(String branch) {
		this.branch = branch;
	}
	
	public void clearRevisionList() {
		this.revisions.clear();
	}
	

}
